Index: content/common/content_switches.cc |
=================================================================== |
--- content/common/content_switches.cc (revision 103113) |
+++ content/common/content_switches.cc (working copy) |
@@ -311,9 +311,9 @@ |
// Make plugin processes log their sent and received messages to VLOG(1). |
const char kLogPluginMessages[] = "log-plugin-messages"; |
-// Uses low-latency IPC for audio. |
-// That is temporary until we make it default and remove old code path. |
-const char kLowLatencyAudio[] = "enable-low-latency-audio"; |
+// Uses high-latency IPC for audio. |
+// That is temporary until we are sure low latency works and remove old code. |
+const char kHighLatencyAudio[] = "disable-low-latency-audio"; |
// Causes the process to run as a NativeClient broker |
// (used for launching NaCl loader processes on 64-bit Windows). |